# Demarches Simpy
![logo](media/logo.png)


A python package to access to Démarches Simplifiées API via OOP objects. 

---

[![MIT License](https://img.shields.io/badge/License-MIT-green.svg)](https://choosealicense.com/licenses/mit/)
[![Demarche Simpy Tests](https://github.com/Z3ZEL/demarches-simpy/actions/workflows/test-python.yml/badge.svg)](https://github.com/Z3ZEL/demarches-simpy/actions/workflows/test-python.yml)
[![Coverage Status](https://coveralls.io/repos/github/Z3ZEL/demarches-simpy/badge.svg?branch=master)](https://coveralls.io/github/Z3ZEL/demarches-simpy?branch=master)
---

- [Demarches Simpy](#demarches-simpy)
  - [](#)
  - [Before you start](#before-you-start)
  - [Installation](#installation)
  - [Get the Démarches Simplifiées API token](#get-the-démarches-simplifiées-api-token)
  - [Getting Started](#getting-started)
  - [Contributing](#contributing)
  - [Documentation](#documentation)
  - [License](#license)


---

## Before you start

**This package is not affiliated with Démarches Simplifiées. It is an unofficial package.**

This package is still in development, some features may not work as expected.

> As Démarches Simplifiées is a French website, the documentation is in english and the package functions are in english, but some object names have been kept in french for clarity. So *Dossier* will be used instead of *Field*. And *Demarche* instead of *Process*. As well as Dossier State like *acceptee* instead of *accepted* and others.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install demarches-simpy:

```bash
pip install demarches-simpy
```

The package was developed with **Python 3.11**, using older versions may cause errors.


## Get the Démarches Simplifiées API token

To use the API, you need to get an API token from the [Démarches Simplifiées website](https://www.demarches-simplifiees.fr/).

Then go to -> "See my profile" -> "API identification tokens" -> "Create and display a new token"

> You can choose to assign the token to specific "demarches" or to all demarches.

## Getting Started

To see how to simply use the package, see the [Getting Started](https://demarches-simpy.readthedocs.io/en/latest/contents/simple_program.html) page in the documentation.

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

## Documentation

[Documentation](https://demarches-simpy.readthedocs.io/en/latest/)


## License

[MIT](https://choosealicense.com/licenses/mit/)

